@@ -7,6 +7,9 @@ Diagram::Diagram(QMainWindow *parent, Alcohol *alc) :
     ui(new Ui::Diagram)
 {
     ui->setupUi(this);
+#ifdef Q_WS_MAEMO_5
+    setAttribute(Qt::WA_Maemo5AutoOrientation, true);
+#endif
     m_alc = alc;
     showDiagram();
 }
@@ -28,6 +31,10 @@ void Diagram::changeEvent(QEvent *e)
     }
 }
 
+void Diagram::resizeEvent(QResizeEvent* event) {
+    showDiagram();
+}
+
 void Diagram::showDiagram()
 {
     const int border = 20;
@@ -47,7 +54,9 @@ void Diagram::showDiagram()
     else {
         QTime driveTime=QTime::currentTime();
         driveTime = driveTime.addSecs(m_alc->getTimeToDrive()*60);
-        ui->lblDriveInfo->setText("You are not allowed to drive your car. Wait until " + driveTime.toString("hh:mm") );
+        ui->lblDriveInfo->setText("You are not allowed to drive your car.\nWait until " + driveTime.toString("hh:mm") );
     }
-    ui->lblDriveInfo->setGeometry(0,this->height()-70, this->width(), 30);
+    ui->lblDriveInfo->setGeometry(0,this->height()-80, this->width(), 60);
 }
+
+
